@@ -1,6 +1,16 @@
-# from PyQt5 import QtCore, QtGui, QtWidgets
+"""UI layout for the right panel of the main window."""
+from __future__ import annotations
+
+from pathlib import Path
 from qtpy import QtCore, QtGui, QtWidgets
 
+__all__ = ["RightPanel"]
+
+
+def get_icon(icon_filename: str) -> str:
+    """Load the path of the icon from the resources folder."""
+    return str(Path(__file__).parent / "icons" / icon_filename)
+
 
 class RightPanel:
     def setupUi(self, Form: QtWidgets.QWidget) -> None:
@@ -25,7 +35,9 @@ class RightPanel:
         font = QtGui.QFont()
         font.setPointSize(12)
         self.active_directory_line_edit.setFont(font)
-        self.active_directory_line_edit.setAlignment(QtCore.Qt.AlignCenter)
+        self.active_directory_line_edit.setAlignment(
+            QtCore.Qt.AlignCenter  # type: ignore
+        )
         self.active_directory_line_edit.setReadOnly(True)
         self.active_directory_line_edit.setObjectName(
             "active_directory_line_edit"
@@ -44,7 +56,9 @@ class RightPanel:
         font = QtGui.QFont()
         font.setPointSize(12)
         self.active_file_line_edit.setFont(font)
-        self.active_file_line_edit.setAlignment(QtCore.Qt.AlignCenter)
+        self.active_directory_line_edit.setAlignment(
+            QtCore.Qt.AlignCenter  # type: ignore
+        )
         self.active_file_line_edit.setReadOnly(True)
         self.active_file_line_edit.setObjectName("active_file_line_edit")
         self.horizontalLayout_8.addWidget(self.active_file_line_edit)
@@ -188,8 +202,8 @@ class RightPanel:
         spacerItem = QtWidgets.QSpacerItem(
             40,
             20,
-            QtWidgets.QSizePolicy.Expanding,
-            QtWidgets.QSizePolicy.Minimum,
+            QtWidgets.QSizePolicy.Expanding,  # type: ignore
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
         )
         self.gridLayout_3.addItem(spacerItem, 0, 0, 1, 1)
         self.verticalLayout_7.addLayout(self.gridLayout_3)
@@ -207,7 +221,8 @@ class RightPanel:
         self.gridLayout_2.setObjectName("gridLayout_2")
         self.pushButton_13 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -218,9 +233,9 @@ class RightPanel:
         self.pushButton_13.setText("")
         icon = QtGui.QIcon()
         icon.addPixmap(
-            QtGui.QPixmap("icons/fast-forward-left.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("fast-forward-left.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_13.setIcon(icon)
         self.pushButton_13.setIconSize(QtCore.QSize(24, 24))
@@ -230,9 +245,9 @@ class RightPanel:
         self.pushButton_15.setText("")
         icon1 = QtGui.QIcon()
         icon1.addPixmap(
-            QtGui.QPixmap("icons/fast-forward-down.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("fast-forward-down.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_15.setIcon(icon1)
         self.pushButton_15.setIconSize(QtCore.QSize(24, 24))
@@ -240,7 +255,8 @@ class RightPanel:
         self.gridLayout_2.addWidget(self.pushButton_15, 5, 6, 1, 1)
         self.pushButton_7 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -251,9 +267,9 @@ class RightPanel:
         self.pushButton_7.setText("")
         icon2 = QtGui.QIcon()
         icon2.addPixmap(
-            QtGui.QPixmap("icons/play-down.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("play-down.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_7.setIcon(icon2)
         self.pushButton_7.setIconSize(QtCore.QSize(24, 24))
@@ -263,9 +279,9 @@ class RightPanel:
         self.pushButton_16.setText("")
         icon3 = QtGui.QIcon()
         icon3.addPixmap(
-            QtGui.QPixmap("icons/play-up.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("play-up.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_16.setIcon(icon3)
         self.pushButton_16.setIconSize(QtCore.QSize(24, 24))
@@ -275,9 +291,9 @@ class RightPanel:
         self.pushButton_17.setText("")
         icon4 = QtGui.QIcon()
         icon4.addPixmap(
-            QtGui.QPixmap("icons/fast-forward-up.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("fast-forward-up.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_17.setIcon(icon4)
         self.pushButton_17.setIconSize(QtCore.QSize(24, 24))
@@ -285,7 +301,8 @@ class RightPanel:
         self.gridLayout_2.addWidget(self.pushButton_17, 1, 6, 1, 1)
         self.pushButton_9 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -301,7 +318,8 @@ class RightPanel:
         self.gridLayout_2.addWidget(self.pushButton_9, 1, 2, 1, 1)
         self.pushButton_6 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -316,7 +334,8 @@ class RightPanel:
         self.gridLayout_2.addWidget(self.pushButton_6, 5, 2, 1, 1)
         self.pushButton_12 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -327,9 +346,9 @@ class RightPanel:
         self.pushButton_12.setText("")
         icon5 = QtGui.QIcon()
         icon5.addPixmap(
-            QtGui.QPixmap("icons/play-left.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("play-left.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_12.setIcon(icon5)
         self.pushButton_12.setIconSize(QtCore.QSize(24, 24))
@@ -339,12 +358,13 @@ class RightPanel:
         font = QtGui.QFont()
         font.setPointSize(12)
         self.label_4.setFont(font)
-        self.label_4.setAlignment(QtCore.Qt.AlignCenter)
+        self.label_4.setAlignment(QtCore.Qt.AlignCenter)  # type: ignore
         self.label_4.setObjectName("label_4")
         self.gridLayout_2.addWidget(self.label_4, 3, 6, 1, 1)
         self.pushButton_10 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type:ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -355,9 +375,9 @@ class RightPanel:
         self.pushButton_10.setText("")
         icon6 = QtGui.QIcon()
         icon6.addPixmap(
-            QtGui.QPixmap("icons/play-right.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("play-right.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_10.setIcon(icon6)
         self.pushButton_10.setIconSize(QtCore.QSize(24, 24))
@@ -365,7 +385,8 @@ class RightPanel:
         self.gridLayout_2.addWidget(self.pushButton_10, 3, 3, 1, 1)
         self.pushButton_11 = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -376,9 +397,9 @@ class RightPanel:
         self.pushButton_11.setText("")
         icon7 = QtGui.QIcon()
         icon7.addPixmap(
-            QtGui.QPixmap("icons/fast-forward-right.png"),
-            QtGui.QIcon.Normal,
-            QtGui.QIcon.On,
+            QtGui.QPixmap(get_icon("fast-forward-right.png")),
+            QtGui.QIcon.Normal,  # type: ignore
+            QtGui.QIcon.On,  # type: ignore
         )
         self.pushButton_11.setIcon(icon7)
         self.pushButton_11.setIconSize(QtCore.QSize(24, 24))
@@ -386,7 +407,8 @@ class RightPanel:
         self.gridLayout_2.addWidget(self.pushButton_11, 3, 4, 1, 1)
         self.fine_xy_up_button = QtWidgets.QPushButton(self.groupBox_4)
         sizePolicy = QtWidgets.QSizePolicy(
-            QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
+            QtWidgets.QSizePolicy.Fixed,  # type: ignore
         )
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -403,7 +425,7 @@ class RightPanel:
         font = QtGui.QFont()
         font.setPointSize(12)
         self.label_3.setFont(font)
-        self.label_3.setAlignment(QtCore.Qt.AlignCenter)
+        self.label_3.setAlignment(QtCore.Qt.AlignCenter)  # type: ignore
         self.label_3.setObjectName("label_3")
         self.gridLayout_2.addWidget(self.label_3, 3, 2, 1, 1)
         self.pushButton_14 = QtWidgets.QPushButton(self.groupBox_4)
@@ -415,15 +437,15 @@ class RightPanel:
         spacerItem1 = QtWidgets.QSpacerItem(
             40,
             20,
-            QtWidgets.QSizePolicy.Expanding,
-            QtWidgets.QSizePolicy.Minimum,
+            QtWidgets.QSizePolicy.Expanding,  # type: ignore
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
         )
         self.gridLayout_2.addItem(spacerItem1, 3, 5, 1, 1)
         spacerItem2 = QtWidgets.QSpacerItem(
             40,
             20,
-            QtWidgets.QSizePolicy.Expanding,
-            QtWidgets.QSizePolicy.Minimum,
+            QtWidgets.QSizePolicy.Expanding,  # type: ignore
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
         )
         self.gridLayout_2.addItem(spacerItem2, 3, 7, 1, 1)
         self.verticalLayout_4.addWidget(self.groupBox_4)
@@ -447,8 +469,8 @@ class RightPanel:
         spacerItem3 = QtWidgets.QSpacerItem(
             40,
             20,
-            QtWidgets.QSizePolicy.Expanding,
-            QtWidgets.QSizePolicy.Minimum,
+            QtWidgets.QSizePolicy.Expanding,  # type: ignore
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
         )
         self.horizontalLayout_5.addItem(spacerItem3)
         self.z_fine_spinbox = QtWidgets.QSpinBox(self.groupBox_3)
@@ -484,8 +506,8 @@ class RightPanel:
         spacerItem4 = QtWidgets.QSpacerItem(
             40,
             20,
-            QtWidgets.QSizePolicy.Expanding,
-            QtWidgets.QSizePolicy.Minimum,
+            QtWidgets.QSizePolicy.Expanding,  # type: ignore
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
         )
         self.horizontalLayout_14.addItem(spacerItem4)
         self.spinBox_3 = QtWidgets.QSpinBox(self.groupBox_3)
@@ -519,8 +541,8 @@ class RightPanel:
         spacerItem5 = QtWidgets.QSpacerItem(
             20,
             40,
-            QtWidgets.QSizePolicy.Minimum,
-            QtWidgets.QSizePolicy.Expanding,
+            QtWidgets.QSizePolicy.Minimum,  # type: ignore
+            QtWidgets.QSizePolicy.Expanding,  # type: ignore
         )
         self.verticalLayout_8.addItem(spacerItem5)
         self.constrastGroupBox = QtWidgets.QGroupBox(self.groupBox_2)
