@@ -1,10 +1,14 @@
+from __future__ import annotations
+
+from pathlib import Path
+
 import numpy as np
 
 from avidaq import napari_get_reader
 
 
 # tmp_path is a pytest fixture
-def test_reader(tmp_path):
+def test_reader(tmp_path: Path) -> None:
     """An example of how you might test your plugin."""
 
     # write some fake data using your supported file format
@@ -26,6 +30,6 @@ def test_reader(tmp_path):
     np.testing.assert_allclose(original_data, layer_data_tuple[0])
 
 
-def test_get_reader_pass():
+def test_get_reader_pass() -> None:
     reader = napari_get_reader("fake.file")
     assert reader is None
